<?php
/*
Plugin Name: Correios API PlugSend
Plugin URI: https://pluginstech.com
Description: Este plugin cria um input na página do pedido para inserir o código de rastreamento dos correios, assim que o código for aplicado ao pedido, será enviado uma mensagem automática com o código de rastreamento dos correios
Version: 1.0
Author: plugins tech
Author URI: https://pluginstech.com
License: 
License URI: 
*/
// Verificar se o WooCommerce está ativo
if (!in_array('woocommerce/woocommerce.php', apply_filters('active_plugins', get_option('active_plugins')))) {
    return;
}

// Adicionar menu em Ferramentas
add_action('admin_menu', 'correios_api_plugsend_menu');
function correios_api_plugsend_menu() {
    add_submenu_page(
        'tools.php',
        'Correios API PlugSend',
        'Correios API PlugSend',
        'manage_options',
        'correios-api-plugsend',
        'correios_api_plugsend_page'
    );
}

// Página de configuração
function correios_api_plugsend_page() {
    if (isset($_POST['submit'])) {
        update_option('whatsapp_api_host', sanitize_text_field($_POST['whatsapp_api_host']));
        update_option('whatsapp_api_connection_key', sanitize_text_field($_POST['whatsapp_api_connection_key']));
        update_option('whatsapp_api_token', sanitize_text_field($_POST['whatsapp_api_token']));
        update_option('whatsapp_codigo_pais', sanitize_text_field($_POST['whatsapp_codigo_pais']));
        update_option('correios_api_plugsend_message', sanitize_textarea_field($_POST['correios_api_plugsend_message']));
        echo '<div class="updated"><p>Configurações salvas.</p></div>';
    }

    $host = get_option('whatsapp_api_host', '');
    $connection_key = get_option('whatsapp_api_connection_key', '');
    $token = get_option('whatsapp_api_token', '');
    $codigo_pais = get_option('whatsapp_codigo_pais', '+55');
    $message = get_option('correios_api_plugsend_message', '');
    ?>
    <div class="wrap">
        <h1>Correios API PlugSend</h1>
        <form method="post" action="">
            <table class="form-table">
                <tr>
                    <th scope="row"><label for="whatsapp_api_host">Host da API do WhatsApp</label></th>
                    <td><input type="text" name="whatsapp_api_host" id="whatsapp_api_host" value="<?php echo esc_attr($host); ?>" class="regular-text"></td>
                </tr>
                <tr>
                    <th scope="row"><label for="whatsapp_api_connection_key">ConnectionKey da API do WhatsApp</label></th>
                    <td><input type="text" name="whatsapp_api_connection_key" id="whatsapp_api_connection_key" value="<?php echo esc_attr($connection_key); ?>" class="regular-text"></td>
                </tr>
                <tr>
                    <th scope="row"><label for="whatsapp_api_token">Token da API do WhatsApp</label></th>
                    <td><input type="text" name="whatsapp_api_token" id="whatsapp_api_token" value="<?php echo esc_attr($token); ?>" class="regular-text"></td>
                </tr>
                <tr>
                    <th scope="row"><label for="whatsapp_codigo_pais">Código do País para WhatsApp</label></th>
                    <td><input type="text" name="whatsapp_codigo_pais" id="whatsapp_codigo_pais" value="<?php echo esc_attr($codigo_pais); ?>" class="regular-text"></td>
                </tr>
                <tr>
                    <th scope="row"><label for="correios_api_plugsend_message">Mensagem de Notificação</label></th>
                    <td>
                        <textarea name="correios_api_plugsend_message" id="correios_api_plugsend_message" rows="5" cols="50" class="large-text"><?php echo esc_textarea($message); ?></textarea>
                        <p class="description">Use {code} para o código de rastreamento, {nome_cliente}, {email_cliente}, {itens_pedido}, {valor_total}, {id_pedido} para dados dinâmicos.</p>
                    </td>
                </tr>
            </table>
            <?php submit_button(); ?>
        </form>
    </div>
    <?php
}

// Adicionar campo de código de rastreamento
add_action('woocommerce_admin_order_data_after_shipping_address', 'wc_add_tracking_code_field');
function wc_add_tracking_code_field($order) {
    $tracking_code = get_post_meta($order->get_id(), '_tracking_code', true);
    ?>
    <div class="tracking-code-container">
        <h3 class="tracking-title"><?php _e('Código de Rastreamento'); ?></h3>
        <div class="tracking-input-container">
            <input type="text" id="tracking_code_input" name="tracking_code_input" value="<?php echo esc_attr($tracking_code); ?>" placeholder="<?php _e('Insira o código de rastreamento'); ?>" />
            <button type="button" class="button button-primary" id="add_tracking_code"><span class="dashicons dashicons-plus"></span> <?php _e('Adicionar'); ?></button>
        </div>
        <?php if ($tracking_code): ?>
            <p id="saved_tracking_code"><strong><?php _e('Código salvo:'); ?></strong> <?php echo esc_html($tracking_code); ?> <button type="button" class="button button-link-delete" id="remove_tracking_code"><span class="dashicons dashicons-no-alt"></span> <?php _e('Remover'); ?></button></p>
        <?php endif; ?>
    </div>
    <style>
        .tracking-code-container {
            margin: 20px 0;
            padding: 15px;
            background-color: #f8f8f8;
            border: 1px solid #ddd;
            border-radius: 4px;
            clear: both;
        }
        .tracking-title {
            margin-top: 0;
            margin-bottom: 15px;
            padding-bottom: 10px;
            border-bottom: 1px solid #ddd;
        }
        .tracking-input-container {
            display: flex;
            align-items: center;
            gap: 10px;
            margin-bottom: 10px;
        }
        #tracking_code_input {
            flex-grow: 1;
            width: auto;
        }
        #add_tracking_code span,
        #remove_tracking_code span {
            vertical-align: middle;
        }
        #saved_tracking_code {
            margin-top: 10px;
            font-size: 14px;
        }
    </style>
    <script type="text/javascript">
    jQuery(document).ready(function($) {
        $('#add_tracking_code').on('click', function() {
            var trackingCode = $('#tracking_code_input').val();
            if (trackingCode) {
                $.post(ajaxurl, {
                    action: 'save_tracking_code',
                    order_id: '<?php echo $order->get_id(); ?>',
                    tracking_code: trackingCode,
                }, function(response) {
                    location.reload();
                });
            }
        });

        $('#remove_tracking_code').on('click', function() {
            if (confirm('<?php _e('Você tem certeza que deseja remover este código?'); ?>')) {
                $.post(ajaxurl, {
                    action: 'remove_tracking_code',
                    order_id: '<?php echo $order->get_id(); ?>',
                }, function(response) {
                    location.reload();
                });
            }
        });
    });
    </script>
    <?php
}

// Salvar código de rastreamento
add_action('wp_ajax_save_tracking_code', 'wc_save_tracking_code');
function wc_save_tracking_code() {
    if (isset($_POST['order_id']) && isset($_POST['tracking_code'])) {
        $order_id = intval($_POST['order_id']);
        $tracking_code = sanitize_text_field($_POST['tracking_code']);
        update_post_meta($order_id, '_tracking_code', $tracking_code);
        
        // Enviar notificação WhatsApp
        send_whatsapp_notification($order_id, $tracking_code);
    }
    wp_die();
}

// Remover código de rastreamento
add_action('wp_ajax_remove_tracking_code', 'wc_remove_tracking_code');
function wc_remove_tracking_code() {
    if (isset($_POST['order_id'])) {
        delete_post_meta(intval($_POST['order_id']), '_tracking_code');
    }
    wp_die();
}

// Função para enviar notificação WhatsApp
function send_whatsapp_notification($order_id, $tracking_code) {
    $order = wc_get_order($order_id);
    if (!$order) return;

    $message_template = get_option('correios_api_plugsend_message', '');
    if (empty($message_template)) return;

    $message = replace_placeholders($message_template, $order, $tracking_code);

    $codigo_pais = get_option('whatsapp_codigo_pais', '+55');
    $telefone_destinatario = preg_replace('/\D/', '', $order->get_billing_phone());
    $telefone_destinatario = $codigo_pais . $telefone_destinatario;

    $host = get_option('whatsapp_api_host');
    $connection_key = get_option('whatsapp_api_connection_key');
    $token = get_option('whatsapp_api_token');
    $api_url = "https://{$host}/message/sendText?connectionKey={$connection_key}";

    if (!$api_url || !$token) {
        error_log('Configurações da API do WhatsApp não estão definidas corretamente.');
        return;
    }

    $data = array(
        'phoneNumber' => $telefone_destinatario,
        'message' => $message
    );

    $response = wp_remote_post($api_url, array(
        'method' => 'POST',
        'headers' => array(
            'Content-Type' => 'application/json',
            'Authorization' => 'Bearer ' . $token
        ),
        'body' => json_encode($data)
    ));

    if (is_wp_error($response)) {
        error_log('Erro ao enviar mensagem pelo WhatsApp: ' . $response->get_error_message());
    }
}

// Função para substituir placeholders
function replace_placeholders($template, $order, $tracking_code) {
    $placeholders = [
        '{code}' => $tracking_code,
        '{id_pedido}' => $order->get_id(),
        '{nome_cliente}' => $order->get_billing_first_name(),
        '{email_cliente}' => $order->get_billing_email(),
        '{valor_total}' => $order->get_total(),
        '{itens_pedido}' => get_order_items_as_string($order)
    ];

    foreach ($placeholders as $key => $value) {
        $template = str_replace($key, $value, $template);
    }
    return $template;
}

// Função para formatar os itens do pedido como string
function get_order_items_as_string($order) {
    $items_string = '';
    foreach ($order->get_items() as $item) {
        $nome_produto = $item->get_name();
        $items_string .= "$nome_produto\n";
    }
    return $items_string;
}